Struct diem_secure_net::NetworkClient[][src]

pub struct NetworkClient { /* fields omitted */ }

Implementations

Blocking read until able to successfully read an entire message

Shutdown the internal network stream

Blocking write until able to successfully send an entire message