Struct diem_secure_net::NetworkServer[][src]

pub struct NetworkServer { /* fields omitted */ }

Implementations

If there isn’t already a downstream client, it accepts. Otherwise it blocks until able to successfully read an entire message

Shutdown the internal network stream

If there isn’t already a downstream client, it accepts. Otherwise it blocks until it is able to successfully send an entire message.