pub struct NetworkServer { /* fields omitted */ }
If there isn’t already a downstream client, it accepts. Otherwise it
blocks until able to successfully read an entire message
Shutdown the internal network stream
If there isn’t already a downstream client, it accepts. Otherwise it
blocks until it is able to successfully send an entire message.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.